@@ -75,6 +75,10 @@ def deploy(model, **kwargs):
     os.remove('./model.dill')
 
   dill.dump(prediction_fn, open('./model.dill', mode='wb'), recurse=True)
+
+  if os.path.exists('./reqs.txt'):
+    os.remove('./reqs.txt')
+
   generate_requirements_file()
 
   zipf = zipfile.ZipFile('model.zip', 'w', zipfile.ZIP_DEFLATED)
@@ -92,6 +96,7 @@ def deploy(model, **kwargs):
 
   os.remove('./model.zip')
   os.remove('./model.dill')
+  os.remove('./reqs.txt')
 
   print('Your model is now deploying! Try it out using this code:\n')
   print('inferrd.get(\'{0}\')([1,2])'.format(name))
