@@ -82,7 +82,12 @@ def generate_requirements_file():
       name = dist.metadata["Name"]
       version = dist.version
 
-      if str(version) == '0.0.0':
+      # don't install version 0.0.0
+      if str(version) == "0.0.0":
+        continue
+
+      # don't install colab packages
+      if "colab" in name:
         continue
 
       requirementsFile.write(f'{name}=={version}\n')
\ No newline at end of file
